@@ -1,7 +1,8 @@
 import sys
 import unittest
 
-from aprsd import email
+from aprsd.plugins import email
+
 
 if sys.version_info >= (3, 2):
     from unittest import mock
@@ -10,8 +11,8 @@ else:
 
 
 class TestMain(unittest.TestCase):
-    @mock.patch("aprsd.email._imap_connect")
-    @mock.patch("aprsd.email._smtp_connect")
+    @mock.patch("aprsd.plugins.email._imap_connect")
+    @mock.patch("aprsd.plugins.email._smtp_connect")
     def test_validate_email(self, imap_mock, smtp_mock):
         """Test to make sure we fail."""
         imap_mock.return_value = None
